<?php
/**
 * News Vibe Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage News Vibe Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function news_vibe_pro_custom_colors_css() {
  	$options= news_vibe_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	## Background Color
	--------------------------------------------------------------*/
	.backtotop,
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.widget_search form.search-form .search-submit:hover,
	.widget_search form.search-form .search-submit:focus,
	input[type="submit"],
	.jetpack_subscription_widget input[type="submit"],
	.jetpack_subscription_widget input[type="submit"]:hover,
	.jetpack_subscription_widget input[type="submit"]:focus,
	#secondary .jetpack_subscription_widget input[type="submit"]:hover,
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.widget_popular_news .post-number,
	.reply a,
	.btn,
	#breaking-news .news-title,
	.widget_posts_slider .slick-arrow,
	.second-design .section-title,
	.second-design .widget-title,
	.second-design .post-categories a,
	.second-design #secondary .post-categories a, 
	.second-design #secondary-sidebar .post-categories a,
	.second-design #colophon .cat-links a,
	.third-design .section-title,
	.third-design .widget-title,
	.third-design .post-categories a,
	.third-design #secondary .post-categories a, 
	.third-design #secondary-sidebar .post-categories a,
	.third-design #colophon .cat-links a {
	    background-color: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Text Color
	--------------------------------------------------------------*/
	a,
	.main-navigation ul.nav-menu li.current-menu-item > a,
	.main-navigation ul.nav-menu li:hover > a,
	.main-navigation a:hover,
	.main-navigation ul.nav-menu > li > a:hover,
	.post-navigation a:hover, 
	.posts-navigation a:hover,
	.post-navigation a:focus, 
	.posts-navigation a:focus,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.widget_featured_post h3 a:hover,
	.widget_featured_post h3 a:focus,
	.widget_featured_post a:hover time,
	.widget_featured_post a:focus time,
	.widget_popular_post a time,
	.widget_popular_post time,
	.widget_latest_post a time,
	.widget_latest_post time,
	.widget_featured_post a time,
	.widget_featured_post time,
	#secondary a:hover,
	#secondary a:focus,
	#secondary-sidebar a:hover,
	#secondary-sidebar a:focus,
	#secondary .post-categories a,
	#secondary-sidebar .post-categories a,
	.widget_posts_filter .widget-title span.active,
	.post-categories a,
	.posted-on a,
	.posted-on a:hover,
	.posted-on a:focus,
	.comment-meta .url:hover,
	.comment-meta .url:focus,
	.comment-metadata a,
	.comment-metadata a time,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.comment-metadata a:hover time,
	.comment-metadata a:focus time,
	.entry-title a:hover,
	.entry-title a:focus,
	#secondary .read-more,
	#secondary-sidebar .read-more,
	.byline a:hover,
	.byline a:focus,
	#colophon .cat-links a {
	    color: '. esc_attr( $color_value ) .';
	}

	.loader-container svg,
	.main-navigation ul.nav-menu li:hover > svg,
	.main-navigation li.menu-item-has-children:hover > a > svg,
	.main-navigation li.menu-item-has-children > a:hover > svg,
	.main-navigation ul.nav-menu > li.current-menu-item > a > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.widget svg,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:focus svg, 
	.navigation.post-navigation a:focus svg,
	#masthead .home-icon > a svg.icon-home {
	    fill: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Border Color
	--------------------------------------------------------------*/
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus {
	    border-color: '. esc_attr( $color_value ) .';
	}

	#breaking-news .news-title:after {
	    border-left-color: '. esc_attr( $color_value ) .';
	}

	.second-design .section-header,
	.second-design .widget-header,
	.third-design .section-header,
	.third-design .widget-header,
	.third-design .section-title:before, 
	.third-design .widget-title:before {
	    border-bottom-color: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Responsive Color
	--------------------------------------------------------------*/
	@media screen and (min-width: 1025px) {
	    #site-navigation {
	        border-top-color: '. esc_attr( $color_value ) .';
	    }
	    #masthead .main-navigation ul.nav-menu li.current-menu-item > a,
	    #masthead .main-navigation ul.nav-menu > li > a:hover,
	    .main-navigation ul.nav-menu li:hover > a {
	        color: '. esc_attr( $color_value ) .';
	    }
	    .main-navigation ul.nav-menu > li:hover > a > svg,
	    .main-navigation ul.nav-menu > li.current-menu-item > a > svg {
	        fill: '. esc_attr( $color_value ) .';
	    }
	    .main-navigation ul.sub-menu li:hover > a,
	    .main-navigation ul.sub-menu li:focus > a {
	        background-color: '. esc_attr( $color_value ) .';
	    }
	}

	/*--------------------------------------------------------------
	## Preloader
	--------------------------------------------------------------*/
	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	    25% {height:30px;transform:translateY(15px);background: '. esc_attr( $color_value ) .';}
	    50% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	    100% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	}
	';

	/**
	 * Filters News Vibe Pro custom colors CSS.
	 *
	 * @since News Vibe Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'news_vibe_pro_custom_colors_css', $css );
}
