<?php
/**
* Most Viewed Section options
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

// Add Most Viewed section
$wp_customize->add_section( 'news_vibe_pro_most_viewed_section', array(
	'title'             => esc_html__( 'Most Viewed','news-vibe-pro' ),
	'description'       => esc_html__( 'Most Viewed Section options.', 'news-vibe-pro' ),
	'panel'             => 'news_vibe_pro_front_page_panel',
	) );

// Most Viewed content enable control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_section_enable]', array(
	'default'			=> 	$options['most_viewed_section_enable'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Switch_Control( $wp_customize, 'news_vibe_pro_theme_options[most_viewed_section_enable]', array(
	'label'             => esc_html__( 'Most Viewed Section Enable', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'on_off_label' 		=> news_vibe_pro_switch_options(),
	) ) );

// most_viewed title setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['most_viewed_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[most_viewed_title]', array(
	'label'           	=> esc_html__( 'Title', 'news-vibe-pro' ),
	'section'        	=> 'news_vibe_pro_most_viewed_section',
	'active_callback' 	=> 'news_vibe_pro_is_most_viewed_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'news_vibe_pro_theme_options[most_viewed_title]', array(
		'selector'            => '#inner-content-wrapper #most-viewed-posts h2.section-title',
		'settings'            => 'news_vibe_pro_theme_options[most_viewed_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'news_vibe_pro_most_viewed_title_partial',
		) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_count]', array(
	'default'          	=> $options['most_viewed_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_most_viewed_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[most_viewed_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'active_callback'   => 'news_vibe_pro_is_most_viewed_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Blog content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_content_type]', array(
	'default'          	=> $options['most_viewed_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[most_viewed_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_most_viewed_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'category' 	=> esc_html__( 'Category', 'news-vibe-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'news-vibe-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['most_viewed_count']; $i++ ) :
// most_viewed pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[most_viewed_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_most_viewed_section_content_page_enable',
	) ) );

// most_viewed posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[most_viewed_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_most_viewed_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[most_viewed_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[most_viewed_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_most_viewed_section_content_category_enable'
	) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'news_vibe_pro_theme_options[most_viewed_category_exclude]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Category_Control( $wp_customize,'news_vibe_pro_theme_options[most_viewed_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press CTRL key select multilple categories.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_most_viewed_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'news_vibe_pro_is_most_viewed_section_content_recent_enable'
	) ) );
