<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'news_vibe_pro_slider_section', array(
	'title'             => esc_html__( 'Slider Section','news-vibe-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'news-vibe-pro' ),
	'panel'             => 'news_vibe_pro_front_page_panel',
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Switch_Control( $wp_customize, 'news_vibe_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'on_off_label' 		=> news_vibe_pro_switch_options(),
	) ) );

// Slider btn title setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_title]', array(
	'default'			=> 	$options['slider_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[slider_title]', array(
	'label'           	=>  esc_html__( 'Title', 'news-vibe-pro' ),
	'section'        	=> 'news_vibe_pro_slider_section',
	'active_callback' 	=> 'news_vibe_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'news_vibe_pro_theme_options[slider_title]', array(
		'selector'            => '#inner-content-wrapper div#main-posts-wrapper div#posts-slider h2.section-title',
		'settings'            => 'news_vibe_pro_theme_options[slider_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'news_vibe_pro_slider_title_partial',
		) );
}

// Slider auto play enable control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_auto_play]', array(
	'default'			=> 	$options['slider_auto_play'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Switch_Control( $wp_customize, 'news_vibe_pro_theme_options[slider_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'on_off_label' 		=> news_vibe_pro_switch_options(),
	'active_callback'   => 'news_vibe_pro_is_slider_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_slider_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Sliders', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'active_callback'   => 'news_vibe_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'category' 	=> esc_html__( 'Category', 'news-vibe-pro' ),
		),
	) );


// slider pages drop down chooser control and setting
for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

// slider_logo pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_slider_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_slider_section_content_page_enable',
	) ) );

// slider_logo posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_slider_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_slider_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_slider_section_content_category_enable'
	) ) );


// slider hr setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[slider_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new News_Vibe_Pro_Customize_Horizontal_Line( $wp_customize, 'news_vibe_pro_theme_options[slider_hr]',
	array(
		'section'         => 'news_vibe_pro_slider_section',
		'active_callback' => 'news_vibe_pro_is_slider_section_enable',
		'type'			  => 'hr'
		) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[relatedpost_count]', array(
	'default'          	=> $options['relatedpost_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_relatedpost_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[relatedpost_count]', array(
	'label'             => esc_html__( 'Number of Related Post', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'active_callback'   => 'news_vibe_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[relatedpost_content_type]', array(
	'default'          	=> $options['relatedpost_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[relatedpost_content_type]', array(
	'label'             => esc_html__( 'Related Post Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'category'	=> esc_html__( 'Category', 'news-vibe-pro'),
		),
	) );

for ( $i = 1; $i <= $options['relatedpost_count']; $i++ ) :

// slider_logo pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[relatedpost_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[relatedpost_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_slider_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_relatedpost_section_content_page_enable',
	) ) );

// slider_logo posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[relatedpost_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[relatedpost_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_slider_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_relatedpost_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[relatedpost_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[relatedpost_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_relatedpost_section_content_category_enable'
	) ) );

