<?php
/**
* Multi Post section
*
* This is the template for the content of multi_post section
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

$options = news_vibe_pro_get_theme_options();

if( $options['multi_post_section_enable'] !== false ):

// Content type.
$multi_post_col1_content_type  = $options['multi_post_col1_content_type'];
$multi_post_col1_count = ! empty( $options['multi_post_col1_count'] ) ? $options['multi_post_col1_count'] : 6;

$content_details = array();
switch ( $multi_post_col1_content_type ) {
    case 'page':
        $page_ids = array();
        for ( $i = 1; $i <= $multi_post_col1_count; $i++ ) {
            if ( ! empty( $options['multi_post_col1_content_page_' . $i] ) )
                $page_ids[] = $options['multi_post_col1_content_page_' . $i];
        }
        $col1_args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $multi_post_col1_count ),
            'orderby'           => 'post__in',
            );
        break;

    case 'post':

        $post_ids = array();
        for ( $i = 1; $i <= $multi_post_col1_count; $i++ ) {
            if ( ! empty( $options['multi_post_col1_content_post_' . $i] ) )
                $post_ids[] = $options['multi_post_col1_content_post_' . $i];
        }
        $col1_args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $multi_post_col1_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );
        break;

    case 'category':
        $cat_ids = ! empty( $options['multi_post_col1_content_category'] ) ? $options['multi_post_col1_content_category'] : '';
        $col1_args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $multi_post_col1_count ),
            'cat'               => absint( $cat_ids ),
            'ignore_sticky_posts'   => true,
            );
        break;
    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $col1_args );
if ( $query->have_posts() ) :
    $content_details['col1']  = array();
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['content']   = get_the_content();
        $page_post['url']       = get_the_permalink();
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

        // Push to the main array.
        array_push( $content_details['col1'], $page_post );
    endwhile;
endif;
wp_reset_postdata();

// Content type.
$multi_post_col2_content_type  = $options['multi_post_col2_content_type'];
$multi_post_col2_count = ! empty( $options['multi_post_col2_count'] ) ? $options['multi_post_col2_count'] : 6;
switch ( $multi_post_col2_content_type ) {
    case 'page':
        $page_ids = array();
        for ( $i = 1; $i <= $multi_post_col2_count; $i++ ) {
            if ( ! empty( $options['multi_post_col2_content_page_' . $i] ) )
                $page_ids[] = $options['multi_post_col2_content_page_' . $i];
        }
        $col2_args = array(
            'post_type'         => 'page',
            'post__in'          => (empty($post_ids)) ? array(0) : ( array ) $page_ids,
            'posts_per_page'    => absint( $multi_post_col2_count ),
            'orderby'           => 'post__in',
            );
        break;

    case 'post':

        $post_ids = array();
        for ( $i = 1; $i <= $multi_post_col2_count; $i++ ) {
            if ( ! empty( $options['multi_post_col2_content_post_' . $i] ) )
                $post_ids[] = $options['multi_post_col2_content_post_' . $i];
        }

        $col2_args = array(
            'post_type'         => 'post',
            'post__in'          => (empty($post_ids)) ? array(0) : ( array ) $post_ids,
            'posts_per_page'    => absint( $multi_post_col2_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );
        break;

    case 'category':
        $cat_ids = ! empty( $options['multi_post_col2_content_category'] ) ? $options['multi_post_col2_content_category'] : '';
        $col2_args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $multi_post_col2_count ),
            'cat'               =>  $cat_ids,
            'ignore_sticky_posts'   => true,
            );
        break;
    default:
    break;
}
// Run The Loop.
$query = new WP_Query( $col2_args );
if ( $query->have_posts() ) :
    $content_details['col2'] = array();
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['content']   = get_the_content();
        $page_post['url']       = get_the_permalink();
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

        // Push to the main array.
        array_push( $content_details['col2'], $page_post );
    endwhile;
endif;
wp_reset_postdata();

if(!empty($content_details)) :?>

    <div id="multiple-posts" class="relative list-layout">
        <div class="<?php echo ( empty($content_details['col1']) || empty($content_details['col2'])) ? 'col-1' : 'col-2'; ?> clear">
            <div class="section-content">
                <div id="col-1" class="section-header">
                    <h2 class="section-title"><?php echo esc_html($options['multi_post_col1_title']); ?></h2>
                </div><!-- .section-header -->

                <?php if(!empty($content_details['col1'])) : ?>
                <div class="world-news">
                    <?php foreach( $content_details['col1'] as $key => $content ) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <a href="<?php echo esc_url($content['url'] ); ?>" class="post-thumbnail-link"></a>
                            <span class="min-read">
                                <?php echo news_vibe_pro_time_interval( $content['content'] ); esc_html_e(' min to read', 'news-vibe-pro'); ?>
                            </span>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span><!-- .cat-links -->

                                <?php if( $key == 0 )  news_vibe_pro_posted_on( $content['id'] ); ?>

                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <?php if( $key == 0 )  echo news_vibe_pro_author( $content['auth_id'] );?>

                        </div><!-- .entry-container -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- #world-news -->
            </div><!-- .section-content -->
            <?php endif; ?>
            
            <?php if(!empty($content_details['col2'])) : ?>
            <div class="section-content">
                <div id="col-2" class="section-header">
                    <h2 class="section-title"><?php echo esc_html($options['multi_post_col2_title']); ?></h2>
                </div><!-- .section-header -->

                <div class="world-news">
                    <?php foreach( $content_details['col2'] as $key => $content ) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <a href="<?php echo esc_url($content['url'] ); ?>" class="post-thumbnail-link"></a>
                            <span class="min-read">
                                <?php echo news_vibe_pro_time_interval( $content['content'] ); esc_html_e(' min to read', 'news-vibe-pro'); ?>
                            </span>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span><!-- .cat-links -->

                                <?php if( $key == 0 )  news_vibe_pro_posted_on( $content['id'] ); ?>

                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <?php if( $key == 0 )  echo news_vibe_pro_author( $content['auth_id'] );?>

                        </div><!-- .entry-container -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- #world-news -->
            </div><!-- .section-content -->
            <?php endif; ?>
        </div><!-- .col-2 -->
    </div><!-- #multiple-posts -->
    <?php endif; ?>
<?php endif; ?>

