<?php
/**
* Slider section
*
* This is the template for the content of slider section
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

$options = news_vibe_pro_get_theme_options();

if($options['slider_section_enable'] !== false ):

// Content type.
$slider_content_type  = $options['slider_content_type'];
$slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
$relatedpost_content_type  = $options['relatedpost_content_type'];
$relatedpost_count = ! empty( $options['relatedpost_count'] ) ? $options['relatedpost_count'] : 6;

$content_details = array();
$content_details['slider'] = array();

switch ( $slider_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $slider_count; $i++ ) {
        if ( ! empty( $options['slider_content_page_' . $i] ) ) :
            $page_ids[] = $options['slider_content_page_' . $i];
        endif;
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $slider_count ),
        'orderby'           => 'post__in',
        );                
    break;

    case 'post':
    $post_ids = array();
    for ( $i = 1; $i <= $slider_count; $i++ ) {
        if ( ! empty( $options['slider_content_post_' . $i] ) ) :
            $post_ids[] = $options['slider_content_post_' . $i];
        endif;
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'     => ( array ) $post_ids,
        'posts_per_page'    => absint( $slider_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                  
    break;

    case 'category':
    $cat_ids = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $slider_count ),
        'cat'               => absint( $cat_ids ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['sub_title'] = ! empty( $options['slider_sub_title'] ) ? $options['slider_sub_title'] : '';
        $page_post['url']       = get_the_permalink();
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details['slider'], $page_post );
endwhile;
endif;
wp_reset_postdata();


$content_details['relatedpost'] = array();

switch ( $relatedpost_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $relatedpost_count; $i++ ) {
        if ( ! empty( $options['relatedpost_content_page_' . $i] ) ) :
            $page_ids[] = $options['relatedpost_content_page_' . $i];
        endif;
    }

    $args1 = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $relatedpost_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $relatedpost_count; $i++ ) {
        if ( ! empty( $options['relatedpost_content_post_' . $i] ) ) :
            $post_ids[] = $options['relatedpost_content_post_' . $i];
        endif;
    }

    $args1 = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $relatedpost_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_ids = ! empty( $options['relatedpost_content_category'] ) ? $options['relatedpost_content_category'] : '';
    $args1 = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $relatedpost_count ),
        'cat'               => absint( $cat_ids ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}


// Run The Loop.
$query = new WP_Query( $args1 );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
$slider_page_post['id']        = get_the_id();
$slider_page_post['auth_id']   = get_the_author_meta('ID');
$slider_page_post['title']     = get_the_title();
$slider_page_post['excerpt']   = get_the_content();
$slider_page_post['url']       = get_the_permalink();
$slider_page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';


// Push to the main array.
array_push( $content_details['relatedpost'], $slider_page_post );
endwhile;
endif;
wp_reset_postdata();
?>

<div id="posts-slider" class="relative">
    <?php if ( ! empty( $options['slider_title'] ) ) : ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['slider_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>
    <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_auto_play'] ? 'true' : 'false'; ?>, "draggable": true, "fade": false }'>
        <?php foreach ( $content_details['slider'] as $content ) : ?>

            <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="entry-container">
                    <div class="entry-meta">
                    <?php if ( $slider_content_type !== 'page' ) : ?>
                        <span class="cat-links">
                            <?php the_category( '', '', $content['id'] ); ?>
                        </span><!-- .cat-links -->
                    <?php endif; ?>

                        <?php news_vibe_pro_posted_on( $content['id'] ); ?>
                    </div><!-- .entry-meta -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>

                    <span class="min-read"><?php echo news_vibe_pro_time_interval( $content['excerpt'] ); echo esc_html__(' min to read', 'news-vibe-pro'); ?></span>
                    <?php echo news_vibe_pro_author( $content['auth_id'] ); ?>
                </div><!-- .entry-container -->
            </article>

        <?php endforeach; ?>
    </div><!-- .featured-slider -->

    <div class="slider-related-posts widget_recent_news col-2 clear">
        <ul>
            <?php foreach( $content_details['relatedpost'] as $content ) : ?>
                <li>
                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                    <div class="entry-container">
                        <div class="entry-meta">
                        <?php if ( $slider_content_type !== 'page' ) : ?>
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->
                        <?php endif; ?>
                        </div><!-- .entry-meta -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>
                    </div><!-- .entry-container -->
                </li>
            <?php endforeach; ?>
        </ul>
    </div><!-- .slider-related-posts -->
</div>
<?php endif; ?>
